﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.IO;
using System.Drawing.Imaging;
using System.Drawing.Drawing2D;

namespace howto_resize_image
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private Bitmap OriginalImage = null;

        private void mnuFileOpen_Click(object sender, EventArgs e)
        {
            if (ofdFile.ShowDialog() == DialogResult.OK)
            {
                OriginalImage = LoadBitmapUnlocked(ofdFile.FileName);
                ShowResult();
            }
        }

        private void mnuFileSave_Click(object sender, EventArgs e)
        {
            if (sfdFile.ShowDialog() == DialogResult.OK)
            {
                if (!sfdFile.FileName.ToLower().EndsWith(".png"))
                {
                    if (MessageBox.Show("Transparency will be lost " +
                        "unless you save with the PNG format. " +
                        "Do you want to save Anyway?",
                        "Save Anyway?", MessageBoxButtons.YesNo)
                            == DialogResult.No)
                    {
                        return;
                    }
                }
                SaveImage(picResult.Image, sfdFile.FileName);
            }
        }

        // Make and show the resized image.
        private void ShowResult()
        {
            lblSize.Text = "Size:";
            picResult.Visible = false;
            if (OriginalImage == null) return;

            // Get the scale.
            float scale;
            if (!float.TryParse(txtScale.Text, out scale))
                return;
            if (scale < 0.0001) return;

            int width = (int)(OriginalImage.Width * scale);
            int height = (int)(OriginalImage.Height * scale);
            lblSize.Text = string.Format("Size: {0} x {1}",
                width, height);

            // Make the resized image.
            Bitmap bm = new Bitmap(width, height);
            using (Graphics gr = Graphics.FromImage(bm))
            {
                gr.InterpolationMode = InterpolationMode.HighQualityBicubic;
                Rectangle dest_rect = new Rectangle(0, 0,
                    width, height);
                Rectangle source_rect = new Rectangle(0, 0,
                    OriginalImage.Width, OriginalImage.Height);
                gr.DrawImage(OriginalImage,
                    dest_rect, source_rect, GraphicsUnit.Pixel);
            }
            picResult.Image = bm;
            picResult.Visible = true;
        }

        private void txtScale_TextChanged(object sender, EventArgs e)
        {
            ShowResult();
        }

        // Save the file with the appropriate format.
        public void SaveImage(Image image, string filename)
        {
            string extension = Path.GetExtension(filename);
            switch (extension.ToLower())
            {
                case ".bmp":
                    image.Save(filename, ImageFormat.Bmp);
                    break;
                case ".exif":
                    image.Save(filename, ImageFormat.Exif);
                    break;
                case ".gif":
                    image.Save(filename, ImageFormat.Gif);
                    break;
                case ".jpg":
                case ".jpeg":
                    image.Save(filename, ImageFormat.Jpeg);
                    break;
                case ".png":
                    image.Save(filename, ImageFormat.Png);
                    break;
                case ".tif":
                case ".tiff":
                    image.Save(filename, ImageFormat.Tiff);
                    break;
                default:
                    throw new NotSupportedException(
                        "Unknown file extension " + extension);
            }
        }

        // Load a bitmap without locking it.
        private Bitmap LoadBitmapUnlocked(string file_name)
        {
            using (Bitmap bm = new Bitmap(file_name))
            {
                return new Bitmap(bm);
            }
        }
    }
}
